@@ -18,13 +18,20 @@ collapseCohorts <- function(cohort,
                             gap = 0,
                             name = tableName(cohort)) {
   # input validation
-  cohort <- validateCohortTable(cohort, dropExtraColumns = TRUE)
+  cohort <- omopgenerics::validateCohortArgument(cohort, dropExtraColumns = TRUE)
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
   cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
-  cohortId <- validateCohortId(cohortId, settings(cohort))
+  cohortId <- omopgenerics::validateCohortIdArgument({{cohortId}}, cohort, validation = "warning")
   omopgenerics::assertNumeric(gap, integerish = TRUE, min = 0, length = 1)
   ids <- settings(cohort)$cohort_definition_id
 
+  if (length(cohortId) == 0) {
+    cli::cli_inform("Returning entry cohort as `cohortId` is not valid.")
+    # return entry cohort as cohortId is used to modify not subset
+    cdm[[name]] <- cohort |> dplyr::compute(name = name, temporary = FALSE)
+    return(cdm[[name]])
+  }
+
   # temp tables
   tablePrefix <- omopgenerics::tmpPrefix()
   tmpNewCohort <- paste0(omopgenerics::uniqueTableName(tablePrefix), "_1")
@@ -73,7 +80,7 @@ collapseCohorts <- function(cohort,
       dplyr::compute(name = name, temporary = FALSE)
   }
   newCohort <- newCohort |>
-    omopgenerics::newCohortTable(.softValidation = TRUE) |>
+    omopgenerics::newCohortTable(.softValidation = FALSE) |>
     omopgenerics::recordCohortAttrition(
       reason = "Collapse cohort with a gap of {gap} days.",
       cohortId = cohortId)
