@@ -67,7 +67,7 @@ test_that("errors", {
 
   expect_error(cdm$cohort |> requireIsFirstEntry(name = 1))
   expect_error(cdm$cohort1 <- cdm$cohort |> requireIsFirstEntry(name = "cohort2"))
-  expect_error(cdm$cohort |> requireIsFirstEntry(cohortId = Inf))
+  expect_warning(cdm$cohort |> requireIsFirstEntry(cohortId = Inf))
   expect_error(cdm$cohort |> dplyr::collect() |> requireIsFirstEntry())
   expect_warning(cdm$cohort |> requireIsFirstEntry(cohortId = c(1, 5)))
 })
@@ -110,7 +110,7 @@ test_that("requireIsLastEntry", {
   # errors
   expect_error(cdm$cohort |> requireIsLastEntry(name = 1))
   expect_error(cdm$cohort1 <- cdm$cohort |> requireIsLastEntry(name = "cohort2"))
-  expect_error(cdm$cohort |> requireIsLastEntry(cohortId = Inf))
+  expect_warning(cdm$cohort |> requireIsLastEntry(cohortId = Inf))
   expect_error(cdm$cohort |> dplyr::collect() |> requireIsLastEntry())
   expect_warning(cdm$cohort |> requireIsLastEntry(cohortId = c(1, 5)))
 })
@@ -166,7 +166,7 @@ test_that("requireEntry", {
  expect_error(cdm$cohort1 |> requireIsEntry(entryRange = "a"))
  expect_error(cdm$cohort1 |> requireIsEntry(entryRange = c(1, 1), name = 1))
  expect_error(cdm$cohort1 <- cdm$cohort1 |> requireIsEntry(entryRange = c(1, 1), name = "cohort2"))
- expect_error(cdm$cohort1 |> requireIsEntry(entryRange = c(1, 1), cohortId = Inf))
+ expect_warning(cdm$cohort1 |> requireIsEntry(entryRange = c(1, 1), cohortId = Inf))
  expect_error(cdm$cohort1 |> dplyr::collect() |> requireIsEntry(entryRange = c(1, 1)))
  expect_warning(cdm$cohort1 |> requireIsEntry(entryRange = c(1, 1), cohortId = c(1, 5)))
 
@@ -224,12 +224,12 @@ test_that("test indexes - postgres", {
                        host = Sys.getenv("CDM5_POSTGRESQL_HOST"),
                        user = Sys.getenv("CDM5_POSTGRESQL_USER"),
                        password = Sys.getenv("CDM5_POSTGRESQL_PASSWORD"))
-  cdm <- CDMConnector::cdm_from_con(
+  cdm <- CDMConnector::cdmFromCon(
     con = db,
-    cdm_schema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
-    write_schema = c(schema =  Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
+    cdmSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
+    writeSchema = c(schema =  Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
                      prefix = "cc_"),
-    achilles_schema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
+    achillesSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
   )
 
   cdm <- omopgenerics::insertTable(cdm = cdm,
@@ -265,5 +265,5 @@ test_that("test indexes - postgres", {
   )
 
   omopgenerics::dropTable(cdm = cdm, name = dplyr::starts_with("my_cohort"))
-  CDMConnector::cdm_disconnect(cdm = cdm)
+  CDMConnector::cdmDisconnect(cdm = cdm)
 })
